pack static method

PackedNode pack(
  1. CircleNode root, {
  2. required double radius,
  3. double minRadiusRatio = 0.1,
})

Packs the root node and its children into a circle with the given radius. minRadiusRatio defines the minimum radius of a child circle as a fraction of the parent radius (default is 0.1, meaning 10% of parent).

Implementation

static PackedNode pack(
  CircleNode root, {
  required double radius,
  double minRadiusRatio = 0.1,
}) {
  return _packNode(root, 0.0, 0.0, radius, minRadiusRatio);
}