FlutterCirclePackChartController class

A controller for the FlutterCirclePackChart that manages the navigation state.

Inheritance

Constructors

FlutterCirclePackChartController({required CircleNode root})

Properties

canGoBack bool
Whether it is possible to navigate back to a parent level.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
root CircleNode
The absolute root of the hierarchy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value CircleNode
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
drillDown(CircleNode node) → void
Drills down into the specified node.
goBack() → void
Navigates back to the previous level in the hierarchy.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited