goBack method
void
goBack()
Navigates back to the previous level in the hierarchy.
Implementation
void goBack() {
if (canGoBack) {
value = _navigationStack.removeLast();
}
}
Navigates back to the previous level in the hierarchy.
void goBack() {
if (canGoBack) {
value = _navigationStack.removeLast();
}
}