controller property
The controller whose navigation state this legend follows. If null, will attempt to find one from a CirclePackProvider scope.
Implementation
final CirclePackChartController? controller;
The controller whose navigation state this legend follows. If null, will attempt to find one from a CirclePackProvider scope.
final CirclePackChartController? controller;