title property
The title for the top-level view. If null, will attempt to find it from a CirclePackProvider scope.
Implementation
final String? title;
The title for the top-level view. If null, will attempt to find it from a CirclePackProvider scope.
final String? title;