FlutterCirclePackChartPainter class
A CustomPainter that renders the circular treemap circles with symmetric explosion/implosion animations and anti-scaled labels.
- Inheritance
-
- Object
- Listenable
- CustomPainter
- FlutterCirclePackChartPainter
Constructors
- FlutterCirclePackChartPainter({required PackedNode root, required CircleNode focusedNode, CircleNode? previousFocusedNode, required double animationValue, required bool isDrillingIn, required double cameraScale, required double baseFontSize})
Properties
- animationValue → double
-
The current progress of the animation (0.0 to 1.0).
final
- baseFontSize → double
-
The base font size for labels (anti-scaled).
final
- cameraScale → double
-
The current camera scale applied to the view.
final
- focusedNode → CircleNode
-
The currently focused node.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDrillingIn → bool
-
Whether we are currently drilling deeper into the hierarchy.
final
- previousFocusedNode → CircleNode?
-
The node that was focused before the current transition.
final
- root → PackedNode
-
The absolute root of the packed hierarchy.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant FlutterCirclePackChartPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited