NodeTransform class

Represents the visual state of a node at a specific point in an animation.

Constructors

NodeTransform({required double x, required double y, required double r, required double opacity})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
opacity double
final
r double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(NodeTransform? a, NodeTransform? b, double t) NodeTransform?
Linearly interpolates between two NodeTransforms.