CirclePacker class
Helper class to perform circle packing calculations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pack(
CircleNode root, {required double radius, double minRadiusRatio = 0.1}) → PackedNode -
Packs the
rootnode and its children into a circle with the givenradius.minRadiusRatiodefines the minimum radius of a child circle as a fraction of the parent radius (default is 0.1, meaning 10% of parent). -
packList(
List< CircleNode> children, {required double radius, String label = 'Root', double minRadiusRatio = 0.1}) → PackedNode -
Packs a list of
childreninto a circle with the givenradius, creating a virtual root with the givenlabel.