PackedNode class
Represents a node that has been positioned and sized in the treemap.
Constructors
-
PackedNode({required CircleNode node, required double x, required double y, required double r, List<
PackedNode> children = const []})
Properties
-
children
→ List<
PackedNode> -
The children of this node, also packed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- node → CircleNode
-
The underlying data node.
final
- r → double
-
The radius of the circle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x → double
-
The x-coordinate of the center (relative to parent or global).
final
- y → double
-
The y-coordinate of the center (relative to parent or global).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited