CircleNode class
Represents a node in the hierarchical data structure for the Circle Pack Chart.
Constructors
-
CircleNode({required String label, double? value, String? displayValue, Color? color, List<
CircleNode> children = const []}) -
CircleNode.fromMap(Map<
String, dynamic> map) -
Creates a CircleNode from a Map.
factory
Properties
-
children
→ List<
CircleNode> -
The nested children of this node.
final
- color → Color?
-
The color associated with this node.
final
- displayValue → String?
-
An optional string representation of the value (e.g. "$1,500").
If provided, this is preferred for display in the chart and legend.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The primary display label for this node (descriptive name).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
Returns the value of this node.
If it has children, the value is the sum of all children values.
Otherwise, it returns the explicitly provided value.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited