FlutterCirclePackChart class

A widget that displays an animated circular treemap with camera-style drill-down.

Inheritance

Constructors

FlutterCirclePackChart({Key? key, required CircleNode root, FlutterCirclePackChartController? controller, double minRadiusRatio = 0.20, double fontSizeFactor = 1.0, bool showValue = true, bool showLabels = true})
const

Properties

controller FlutterCirclePackChartController?
Optional controller to manage the navigation state.
final
fontSizeFactor double
A factor to adjust the automatically calculated responsive font size. Defaults to 1.0. Higher values make text larger globally.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minRadiusRatio double
Defines the minimum radius of a child circle as a fraction of its parent. Defaults to 0.20 to allow better visual hierarchy while maintaining labels.
final
root CircleNode
The root node of the hierarchical data to display.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabels bool
Whether to show the CircleNode.label inside the circles. Defaults to true.
final
showValue bool
Whether to show the CircleNode.value (or CircleNode.displayValue) inside the circles. Defaults to true.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutterCirclePackChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited